.. :changelog:

History
-------


0.0.2 (2017-09-20)
___________________________

* Fixed Bus object so my_bus.o[m:n] now calls my_bus(m, n) to get a shadow slice instead of creating an array of wires.


0.0.1 (2017-08-30)
___________________________

* First release on PyPI.
